use std::collections::HashMap;

use anyhow::{ensure, Result};

use crate::option_flags::OptionFlags;
use crate::rom::RomData;

pub struct Randomization {
    rom: RomData,
    option_flags: OptionFlags,
    bosses_gfx_index: HashMap<String, u8>,
}

impl RomData {
    pub fn randomize(&mut self, option_flags: OptionFlags, seed: i32) -> anyhow::Result<()> {
        ensure!(self.is_randomizer(), "Enemizer only supports randomizer ROMs for input.");
        ensure!(!self.is_race(), "Enemizer does not support race roms.");

        if self.is_enemizer() {
            // Reuse seed in ROM, not the one given.
            self.reset_enemizer();
        } else {
            self.set_enemizer_seed(seed);
        }

        self.set_info_flags(option_flags)?;

        Ok(())
    }
}
